Exception: ReactorSDK::AuthorizationError

Inherits:
Error
  • Object
show all
Defined in:
lib/reactor_sdk/error.rb

Overview

Raised when the token is valid but lacks permission for the resource. Most commonly caused by the org not having access to a property.

Instance Attribute Summary

Attributes inherited from Error

#cause, #status

Method Summary

Methods inherited from Error

#initialize

Constructor Details

This class inherits a constructor from ReactorSDK::Error