Class: ReactorSDK::Resources::Build
- Inherits:
-
BaseResource
- Object
- BaseResource
- ReactorSDK::Resources::Build
- Defined in:
- lib/reactor_sdk/resources/build.rb
Instance Attribute Summary
Attributes inherited from BaseResource
#attributes, #id, #meta, #relationships, #type
Instance Method Summary collapse
-
#created_at ⇒ String
ISO8601 timestamp when the build was created.
-
#failed? ⇒ Boolean
Returns true if the build failed.
-
#inspect ⇒ String
Human-readable representation.
-
#pending? ⇒ Boolean
Returns true if the build is still in progress.
-
#status ⇒ String
Current build status One of: “pending”, “processing”, “succeeded”, “failed”, “rejected”.
-
#succeeded? ⇒ Boolean
Returns true if the build completed successfully.
-
#updated_at ⇒ String
ISO8601 timestamp when the build was last updated.
Methods inherited from BaseResource
#==, #[], attribute, #initialize, #relationship_data, #relationship_id, #relationship_ids, #to_h
Constructor Details
This class inherits a constructor from ReactorSDK::Resources::BaseResource
Instance Method Details
#created_at ⇒ String
Returns ISO8601 timestamp when the build was created.
24 |
# File 'lib/reactor_sdk/resources/build.rb', line 24 attribute :created_at |
#failed? ⇒ Boolean
Returns true if the build failed.
52 53 54 |
# File 'lib/reactor_sdk/resources/build.rb', line 52 def failed? status == 'failed' end |
#inspect ⇒ String
Returns Human-readable representation.
59 60 61 |
# File 'lib/reactor_sdk/resources/build.rb', line 59 def inspect "#<ReactorSDK::Resources::Build id=#{id.inspect} status=#{status.inspect}>" end |
#pending? ⇒ Boolean
Returns true if the build is still in progress.
43 44 45 |
# File 'lib/reactor_sdk/resources/build.rb', line 43 def pending? %w[pending processing].include?(status) end |
#status ⇒ String
Returns Current build status One of: “pending”, “processing”, “succeeded”, “failed”, “rejected”.
21 |
# File 'lib/reactor_sdk/resources/build.rb', line 21 attribute :status |
#succeeded? ⇒ Boolean
Returns true if the build completed successfully.
34 35 36 |
# File 'lib/reactor_sdk/resources/build.rb', line 34 def succeeded? status == 'succeeded' end |
#updated_at ⇒ String
Returns ISO8601 timestamp when the build was last updated.
27 |
# File 'lib/reactor_sdk/resources/build.rb', line 27 attribute :updated_at |