Class: ReactorSDK::Resources::Library
- Inherits:
-
BaseResource
- Object
- BaseResource
- ReactorSDK::Resources::Library
- Defined in:
- lib/reactor_sdk/resources/library.rb
Instance Attribute Summary
Attributes inherited from BaseResource
#attributes, #id, #meta, #relationships, #type
Instance Method Summary collapse
-
#build_required_detail ⇒ String?
ISO8601 timestamp when the library build completed.
-
#buildable? ⇒ Boolean
Returns true if the library is in a state where it can be built.
-
#created_at ⇒ String
ISO8601 timestamp when the library was created.
-
#inspect ⇒ String
Human-readable representation.
-
#name ⇒ String
Display name of the library.
-
#published ⇒ Boolean
Whether the library has been published.
-
#published? ⇒ Boolean
Returns true if the library has been successfully published.
-
#published_at ⇒ String?
ISO8601 timestamp when the library was published.
-
#state ⇒ String
Current state of the library in its workflow One of: “development”, “submitted”, “approved”, “rejected”, “published”.
-
#updated_at ⇒ String
ISO8601 timestamp when the library was last updated.
Methods inherited from BaseResource
#==, #[], attribute, #initialize, #relationship_data, #relationship_id, #relationship_ids, #to_h
Constructor Details
This class inherits a constructor from ReactorSDK::Resources::BaseResource
Instance Method Details
#build_required_detail ⇒ String?
Returns ISO8601 timestamp when the library build completed.
39 |
# File 'lib/reactor_sdk/resources/library.rb', line 39 attribute :build_required_detail |
#buildable? ⇒ Boolean
Returns true if the library is in a state where it can be built.
46 47 48 |
# File 'lib/reactor_sdk/resources/library.rb', line 46 def buildable? state == 'development' end |
#created_at ⇒ String
Returns ISO8601 timestamp when the library was created.
30 |
# File 'lib/reactor_sdk/resources/library.rb', line 30 attribute :created_at |
#inspect ⇒ String
Returns Human-readable representation.
62 63 64 |
# File 'lib/reactor_sdk/resources/library.rb', line 62 def inspect "#<ReactorSDK::Resources::Library id=#{id.inspect} name=#{name.inspect} state=#{state.inspect}>" end |
#name ⇒ String
Returns Display name of the library.
20 |
# File 'lib/reactor_sdk/resources/library.rb', line 20 attribute :name |
#published ⇒ Boolean
Returns Whether the library has been published.
27 |
# File 'lib/reactor_sdk/resources/library.rb', line 27 attribute :published, as: :boolean |
#published? ⇒ Boolean
Returns true if the library has been successfully published.
55 56 57 |
# File 'lib/reactor_sdk/resources/library.rb', line 55 def published? state == 'published' end |
#published_at ⇒ String?
Returns ISO8601 timestamp when the library was published.
36 |
# File 'lib/reactor_sdk/resources/library.rb', line 36 attribute :published_at |
#state ⇒ String
Returns Current state of the library in its workflow One of: “development”, “submitted”, “approved”, “rejected”, “published”.
24 |
# File 'lib/reactor_sdk/resources/library.rb', line 24 attribute :state |
#updated_at ⇒ String
Returns ISO8601 timestamp when the library was last updated.
33 |
# File 'lib/reactor_sdk/resources/library.rb', line 33 attribute :updated_at |